import 'package:flutter_test/flutter_test.dart';
import 'package:integration_test/integration_test.dart';
import 'package:quickblox_sdk/auth/module.dart';
import 'package:quickblox_sdk/chat/constants.dart';
import 'package:quickblox_sdk/models/qb_dialog.dart';
import 'package:quickblox_sdk/models/qb_filter.dart';
import 'package:quickblox_sdk/quickblox_sdk.dart';

import '../base_test.dart';

void main() {
  IntegrationTestWidgetsFlutterBinding.ensureInitialized();

  setUpAll(() async {
    await BaseTest.initCredentials();
  });

  setUp(() async {
    QBLoginResult loginResult = await BaseTest.login();
    expect(loginResult.qbSession?.applicationId, int.parse(BaseTest.APP_ID));
    expect(loginResult.qbUser?.login, BaseTest.USER_LOGIN);
    expect(loginResult.qbUser?.id, int.parse(BaseTest.USER_ID));
  });

  tearDown(() async {
    await BaseTest.logout();
  });

  test("get dialogs by filter", () async {
    QBFilter filter = QBFilter();
    filter.field = QBChatDialogFilterFields.ID;
    filter.value = BaseTest.DIALOG_ID;
    filter.operator = QBChatDialogFilterOperators.ALL;

    List<QBDialog?> dialogs = await QB.chat.getDialogs(filter: filter);
    expect(dialogs.length == 1, true);
  });
}
