///Created by Injoit on 2022-04-06.
///Copyright © 2022 Quickblox. All rights reserved.
import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:integration_test/integration_test.dart';
import 'package:quickblox_sdk/models/qb_ice_server.dart';
import 'package:quickblox_sdk/quickblox_sdk.dart';

import 'utils/ice_server_util.dart';

void main() {
  IntegrationTestWidgetsFlutterBinding.ensureInitialized();

  test("set correct ice servers test", () async {
    await QB.rtcConfig.setIceServers(IceServerUtil.buildCorrectIceServers());
  }, timeout:Timeout.none);

  test("set wrong ice servers test", () async {
    try {
      await QB.rtcConfig.setIceServers(IceServerUtil.buildWrongIceServers());
      fail("Expected: Exception, actual: No thrown Exception");
    } on PlatformException catch (e) {
      expect(e, e);
    }
  }, timeout:Timeout.none);

  test("set empty ice servers test", () async {
    try {
      await QB.rtcConfig.setIceServers([]);
      fail("Expected: Exception, actual: No thrown Exception");
    } on PlatformException catch (e) {
      expect(e, e);
    }
  });

  test("set 3 Correct 1 Wrong ice servers test", () async {
    try {
      await QB.rtcConfig.setIceServers(IceServerUtil.build_3_correct_1_wrong_IceServers());
      fail("Expected: Exception, actual: No thrown Exception");
    } on PlatformException catch (e) {
      expect(e, e);
    }
  });

  test("set correct and get correct ice servers test", () async {
    List<QBIceServer> uploadedServers = IceServerUtil.buildCorrectIceServers();
    await QB.rtcConfig.setIceServers(uploadedServers);

    List<QBIceServer> downloadedServers = await QB.rtcConfig.getIceServers();
    expect(uploadedServers.length == downloadedServers.length, true);
  });

  test("get default ice servers test", () async {
    List<QBIceServer> downloadedServers = await QB.rtcConfig.getIceServers();
    expect(downloadedServers.length > 0, true);
  });

  test("set wrong and get default ice servers test", () async {
    try {
      await QB.rtcConfig.setIceServers(IceServerUtil.buildWrongIceServers());
      fail("expected: error, actual: success");
    } on PlatformException catch (e) {
      expect(e, e);
    }

    List<QBIceServer> downloadedServers = await QB.rtcConfig.getIceServers();
    expect(downloadedServers.length > 0, true);
  });
}
